@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2011-2015 Michael Goffioul
+Copyright (C) 2011-2016 Michael Goffioul
 
 This file is part of Octave.
 
@@ -20,8 +20,8 @@ along with Octave; see the file COPYING.  If not, see
 
 */
 
-#ifndef __QtHandles_Menu__
-#define __QtHandles_Menu__ 1
+#if ! defined (octave_Menu_h)
+#define octave_Menu_h 1
 
 #include "MenuContainer.h"
 #include "Object.h"
@@ -33,35 +33,36 @@ class QWidget;
 namespace QtHandles
 {
 
-class Menu : public Object, public MenuContainer
-{
-  Q_OBJECT
+  class Menu : public Object, public MenuContainer
+  {
+    Q_OBJECT
 
-public:
-  Menu (const graphics_object& go, QAction* action, Object* parent);
-  ~Menu (void);
+  public:
+    Menu (const graphics_object& go, QAction* action, Object* parent);
+    ~Menu (void);
 
-  static Menu* create (const graphics_object& go);
+    static Menu* create (const graphics_object& go);
 
-  Container* innerContainer (void) { return 0; }
+    Container* innerContainer (void) { return 0; }
 
-  QWidget* menu (void);
+    QWidget* menu (void);
 
-protected:
-  void update (int pId);
+  protected:
+    void update (int pId);
 
-private slots:
-  void actionTriggered (void);
-  void actionHovered (void);
+  private slots:
+    void actionTriggered (void);
+    void actionHovered (void);
 
-private:
-  void updateSiblingPositions (void);
+  private:
+    void updateSiblingPositions (void);
 
-private:
-  QWidget* m_parent;
-  QAction* m_separator;
-};
+  private:
+    QWidget* m_parent;
+    QAction* m_separator;
+  };
 
-}; // namespace QtHandles
+}
 
 #endif
+
