@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2011-2015 Michael Goffioul
+Copyright (C) 2011-2016 Michael Goffioul
 
 This file is part of Octave.
 
@@ -20,8 +20,8 @@ along with Octave; see the file COPYING.  If not, see
 
 */
 
-#ifndef __QtHandles_ObjectProxy__
-#define __QtHandles_ObjectProxy__ 1
+#if ! defined (octave_ObjectProxy_h)
+#define octave_ObjectProxy_h 1
 
 #include <QObject>
 
@@ -30,36 +30,37 @@ class QString;
 namespace QtHandles
 {
 
-class Object;
+  class Object;
 
-class ObjectProxy : public QObject
-{
-  Q_OBJECT
+  class ObjectProxy : public QObject
+  {
+    Q_OBJECT
 
-public:
-   ObjectProxy (Object* obj = 0);
+  public:
+    ObjectProxy (Object* obj = 0);
 
-   void update (int pId);
-   void finalize (void);
-   void redraw (void);
-   void print (const QString& file_cmd, const QString& term);
+    void update (int pId);
+    void finalize (void);
+    void redraw (void);
+    void print (const QString& file_cmd, const QString& term);
 
-   Object* object (void) { return m_object; }
-   void setObject (Object* obj);
+    Object* object (void) { return m_object; }
+    void setObject (Object* obj);
 
-signals:
-   void sendUpdate (int pId);
-   void sendFinalize (void);
-   void sendRedraw (void);
-   void sendPrint (const QString& file_cmd, const QString& term);
+  signals:
+    void sendUpdate (int pId);
+    void sendFinalize (void);
+    void sendRedraw (void);
+    void sendPrint (const QString& file_cmd, const QString& term);
 
-private:
-   void init (Object* obj);
+  private:
+    void init (Object* obj);
 
-private:
-   Object* m_object;
-};
+  private:
+    Object* m_object;
+  };
 
 };
 
 #endif
+
