@@ -1,7 +1,7 @@
 /*
 
-Copyright (C) 2013-2015 John W. Eaton
-Copyright (C) 2011-2015 Jacob Dawid
+Copyright (C) 2013-2016 John W. Eaton
+Copyright (C) 2011-2016 Jacob Dawid
 
 This file is part of Octave.
 
@@ -21,8 +21,8 @@ along with Octave; see the file COPYING.  If not, see
 
 */
 
-#ifndef WELCOMEWIZARD_H
-#define WELCOMEWIZARD_H
+#if ! defined (octave_welcome_wizard_h)
+#define octave_welcome_wizard_h 1
 
 #include <QDialog>
 #include <QCheckBox>
@@ -132,4 +132,5 @@ private:
   QPushButton *cancel;
 };
 
-#endif // WELCOMEWIZARD_H
+#endif
+
