@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996-2015 John W. Eaton
+Copyright (C) 1996-2016 John W. Eaton
 
 This file is part of Octave.
 
@@ -20,8 +20,8 @@ along with Octave; see the file COPYING.  If not, see
 
 */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
+#if defined (HAVE_CONFIG_H)
+#  include "config.h"
 #endif
 
 #include <iostream>
@@ -31,7 +31,7 @@ along with Octave; see the file COPYING.  If not, see
 #include "lo-mappers.h"
 
 #include "mxarray.h"
-#include "oct-obj.h"
+#include "ovl.h"
 #include "oct-hdf5.h"
 #include "oct-stream.h"
 #include "ops.h"
@@ -42,11 +42,11 @@ along with Octave; see the file COPYING.  If not, see
 #include "ov-flt-cx-mat.h"
 #include "ov-float.h"
 #include "ov-flt-complex.h"
-#include "gripes.h"
+#include "errwarn.h"
 #include "pr-output.h"
 #include "ops.h"
 
-#include "ls-oct-ascii.h"
+#include "ls-oct-text.h"
 #include "ls-hdf5.h"
 
 // Prevent implicit instantiations on some systems (Windows, others?)
@@ -54,10 +54,8 @@ along with Octave; see the file COPYING.  If not, see
 
 extern template class OCTINTERP_API octave_base_scalar<float>;
 
-
 template class octave_base_scalar<FloatComplex>;
 
-
 DEFINE_OV_TYPEID_FUNCTIONS_AND_DATA (octave_float_complex,
                                      "float complex scalar", "single");
 
@@ -66,10 +64,10 @@ octave_float_complex::try_narrowing_conversion (void)
 {
   octave_base_value *retval = 0;
 
-  float im = std::imag (scalar);
+  float im = scalar.imag ();
 
   if (im == 0.0)
-    retval = new octave_float_scalar (std::real (scalar));
+    retval = new octave_float_scalar (scalar.real ());
 
   return retval;
 }
@@ -96,29 +94,21 @@ octave_float_complex::do_index_op (const octave_value_list& idx, bool resize_ok)
 double
 octave_float_complex::double_value (bool force_conversion) const
 {
-  double retval;
-
   if (! force_conversion)
-    gripe_implicit_conversion ("Octave:imag-to-real",
-                               "complex scalar", "real scalar");
+    warn_implicit_conversion ("Octave:imag-to-real",
+                              "complex scalar", "real scalar");
 
-  retval = std::real (scalar);
-
-  return retval;
+  return scalar.real ();
 }
 
 float
 octave_float_complex::float_value (bool force_conversion) const
 {
-  float retval;
-
   if (! force_conversion)
-    gripe_implicit_conversion ("Octave:imag-to-real",
-                               "complex scalar", "real scalar");
+    warn_implicit_conversion ("Octave:imag-to-real",
+                              "complex scalar", "real scalar");
 
-  retval = std::real (scalar);
-
-  return retval;
+  return scalar.real ();
 }
 
 Matrix
@@ -127,10 +117,10 @@ octave_float_complex::matrix_value (bool force_conversion) const
   Matrix retval;
 
   if (! force_conversion)
-    gripe_implicit_conversion ("Octave:imag-to-real",
-                               "complex scalar", "real matrix");
+    warn_implicit_conversion ("Octave:imag-to-real",
+                              "complex scalar", "real matrix");
 
-  retval = Matrix (1, 1, std::real (scalar));
+  retval = Matrix (1, 1, scalar.real ());
 
   return retval;
 }
@@ -141,10 +131,10 @@ octave_float_complex::float_matrix_value (bool force_conversion) const
   FloatMatrix retval;
 
   if (! force_conversion)
-    gripe_implicit_conversion ("Octave:imag-to-real",
-                               "complex scalar", "real matrix");
+    warn_implicit_conversion ("Octave:imag-to-real",
+                              "complex scalar", "real matrix");
 
-  retval = FloatMatrix (1, 1, std::real (scalar));
+  retval = FloatMatrix (1, 1, scalar.real ());
 
   return retval;
 }
@@ -155,10 +145,10 @@ octave_float_complex::array_value (bool force_conversion) const
   NDArray retval;
 
   if (! force_conversion)
-    gripe_implicit_conversion ("Octave:imag-to-real",
-                               "complex scalar", "real matrix");
+    warn_implicit_conversion ("Octave:imag-to-real",
+                              "complex scalar", "real matrix");
 
-  retval = NDArray (dim_vector (1, 1), std::real (scalar));
+  retval = NDArray (dim_vector (1, 1), scalar.real ());
 
   return retval;
 }
@@ -169,10 +159,10 @@ octave_float_complex::float_array_value (bool force_conversion) const
   FloatNDArray retval;
 
   if (! force_conversion)
-    gripe_implicit_conversion ("Octave:imag-to-real",
-                               "complex scalar", "real matrix");
+    warn_implicit_conversion ("Octave:imag-to-real",
+                              "complex scalar", "real matrix");
 
-  retval = FloatNDArray (dim_vector (1, 1), std::real (scalar));
+  retval = FloatNDArray (dim_vector (1, 1), scalar.real ());
 
   return retval;
 }
@@ -236,6 +226,18 @@ octave_float_complex::resize (const dim_vector& dv, bool fill) const
     }
 }
 
+octave_value
+octave_float_complex::as_double (void) const
+{
+  return Complex (scalar);
+}
+
+octave_value
+octave_float_complex::as_single (void) const
+{
+  return scalar;
+}
+
 octave_value
 octave_float_complex::diag (octave_idx_type m, octave_idx_type n) const
 {
@@ -261,16 +263,12 @@ octave_float_complex::load_ascii (std::istream& is)
 {
   scalar = octave_read_value<FloatComplex> (is);
 
-  if (!is)
-    {
-      error ("load: failed to load complex scalar constant");
-      return false;
-    }
+  if (! is)
+    error ("load: failed to load complex scalar constant");
 
   return true;
 }
 
-
 bool
 octave_float_complex::save_binary (std::ostream& os, bool& /* save_as_floats */)
 {
@@ -284,7 +282,7 @@ octave_float_complex::save_binary (std::ostream& os, bool& /* save_as_floats */)
 
 bool
 octave_float_complex::load_binary (std::istream& is, bool swap,
-                                   oct_mach_info::float_format fmt)
+                                   octave::mach_info::float_format fmt)
 {
   char tmp;
   if (! is.read (reinterpret_cast<char *> (&tmp), 1))
@@ -293,7 +291,8 @@ octave_float_complex::load_binary (std::istream& is, bool swap,
   FloatComplex ctmp;
   read_floats (is, reinterpret_cast<float *> (&ctmp),
                static_cast<save_type> (tmp), 2, swap, fmt);
-  if (error_state || ! is)
+
+  if (! is)
     return false;
 
   scalar = ctmp;
@@ -322,11 +321,11 @@ octave_float_complex::save_hdf5 (octave_hdf5_id loc_id, const char *name,
       H5Sclose (space_hid);
       return false;
     }
-#if HAVE_HDF5_18
+#if defined (HAVE_HDF5_18)
   data_hid = H5Dcreate (loc_id, name, type_hid, space_hid,
-                        H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
+                        octave_H5P_DEFAULT, octave_H5P_DEFAULT, octave_H5P_DEFAULT);
 #else
-  data_hid = H5Dcreate (loc_id, name, type_hid, space_hid, H5P_DEFAULT);
+  data_hid = H5Dcreate (loc_id, name, type_hid, space_hid, octave_H5P_DEFAULT);
 #endif
   if (data_hid < 0)
     {
@@ -336,15 +335,18 @@ octave_float_complex::save_hdf5 (octave_hdf5_id loc_id, const char *name,
     }
 
   FloatComplex tmp = float_complex_value ();
-  retval = H5Dwrite (data_hid, type_hid, H5S_ALL, H5S_ALL, H5P_DEFAULT,
-                     &tmp) >= 0;
+  retval = H5Dwrite (data_hid, type_hid, octave_H5S_ALL, octave_H5S_ALL,
+                     octave_H5P_DEFAULT, &tmp) >= 0;
 
   H5Dclose (data_hid);
   H5Tclose (type_hid);
   H5Sclose (space_hid);
 
 #else
-  gripe_save ("hdf5");
+  octave_unused_parameter (loc_id);
+  octave_unused_parameter (name);
+
+  warn_save ("hdf5");
 #endif
 
   return retval;
@@ -357,8 +359,8 @@ octave_float_complex::load_hdf5 (octave_hdf5_id loc_id, const char *name)
 
 #if defined (HAVE_HDF5)
 
-#if HAVE_HDF5_18
-  hid_t data_hid = H5Dopen (loc_id, name, H5P_DEFAULT);
+#if defined (HAVE_HDF5_18)
+  hid_t data_hid = H5Dopen (loc_id, name, octave_H5P_DEFAULT);
 #else
   hid_t data_hid = H5Dopen (loc_id, name);
 #endif
@@ -386,8 +388,9 @@ octave_float_complex::load_hdf5 (octave_hdf5_id loc_id, const char *name)
 
   // complex scalar:
   FloatComplex ctmp;
-  if (H5Dread (data_hid, complex_type, H5S_ALL, H5S_ALL, H5P_DEFAULT,
-               &ctmp) >= 0)
+  if (H5Dread (data_hid, complex_type, octave_H5S_ALL, octave_H5S_ALL,
+               octave_H5P_DEFAULT, &ctmp)
+      >= 0)
     {
       retval = true;
       scalar = ctmp;
@@ -398,7 +401,10 @@ octave_float_complex::load_hdf5 (octave_hdf5_id loc_id, const char *name)
   H5Dclose (data_hid);
 
 #else
-  gripe_load ("hdf5");
+  octave_unused_parameter (loc_id);
+  octave_unused_parameter (name);
+
+  warn_load ("hdf5");
 #endif
 
   return retval;
@@ -412,8 +418,8 @@ octave_float_complex::as_mxArray (void) const
   float *pr = static_cast<float *> (retval->get_data ());
   float *pi = static_cast<float *> (retval->get_imag_data ());
 
-  pr[0] = std::real (scalar);
-  pi[0] = std::imag (scalar);
+  pr[0] = scalar.real ();
+  pi[0] = scalar.imag ();
 
   return retval;
 }
@@ -423,52 +429,53 @@ octave_float_complex::map (unary_mapper_t umap) const
 {
   switch (umap)
     {
-#define SCALAR_MAPPER(UMAP, FCN) \
-    case umap_ ## UMAP: \
+#define SCALAR_MAPPER(UMAP, FCN)              \
+    case umap_ ## UMAP:                       \
       return octave_value (FCN (scalar))
 
-      SCALAR_MAPPER (abs, std::abs);
-      SCALAR_MAPPER (acos, ::acos);
-      SCALAR_MAPPER (acosh, ::acosh);
-      SCALAR_MAPPER (angle, std::arg);
-      SCALAR_MAPPER (arg, std::arg);
-      SCALAR_MAPPER (asin, ::asin);
-      SCALAR_MAPPER (asinh, ::asinh);
-      SCALAR_MAPPER (atan, ::atan);
-      SCALAR_MAPPER (atanh, ::atanh);
-      SCALAR_MAPPER (erf, ::erf);
-      SCALAR_MAPPER (erfc, ::erfc);
-      SCALAR_MAPPER (erfcx, ::erfcx);
-      SCALAR_MAPPER (erfi, ::erfi);
-      SCALAR_MAPPER (dawson, ::dawson);
-      SCALAR_MAPPER (ceil, ::ceil);
-      SCALAR_MAPPER (conj, std::conj);
-      SCALAR_MAPPER (cos, std::cos);
-      SCALAR_MAPPER (cosh, std::cosh);
-      SCALAR_MAPPER (exp, std::exp);
-      SCALAR_MAPPER (expm1, ::expm1);
-      SCALAR_MAPPER (fix, ::fix);
-      SCALAR_MAPPER (floor, ::floor);
-      SCALAR_MAPPER (imag, std::imag);
-      SCALAR_MAPPER (log, std::log);
-      SCALAR_MAPPER (log2, xlog2);
-      SCALAR_MAPPER (log10, std::log10);
-      SCALAR_MAPPER (log1p, ::log1p);
-      SCALAR_MAPPER (real, std::real);
-      SCALAR_MAPPER (round, xround);
-      SCALAR_MAPPER (roundb, xroundb);
-      SCALAR_MAPPER (signum, ::signum);
-      SCALAR_MAPPER (sin, std::sin);
-      SCALAR_MAPPER (sinh, std::sinh);
-      SCALAR_MAPPER (sqrt, std::sqrt);
-      SCALAR_MAPPER (tan, std::tan);
-      SCALAR_MAPPER (tanh, std::tanh);
-      SCALAR_MAPPER (finite, xfinite);
-      SCALAR_MAPPER (isinf, xisinf);
-      SCALAR_MAPPER (isna, octave_is_NA);
-      SCALAR_MAPPER (isnan, xisnan);
+    SCALAR_MAPPER (abs, std::abs);
+    SCALAR_MAPPER (acos, octave::math::acos);
+    SCALAR_MAPPER (acosh, octave::math::acosh);
+    SCALAR_MAPPER (angle, std::arg);
+    SCALAR_MAPPER (arg, std::arg);
+    SCALAR_MAPPER (asin, octave::math::asin);
+    SCALAR_MAPPER (asinh, octave::math::asinh);
+    SCALAR_MAPPER (atan, octave::math::atan);
+    SCALAR_MAPPER (atanh, octave::math::atanh);
+    SCALAR_MAPPER (erf, octave::math::erf);
+    SCALAR_MAPPER (erfc, octave::math::erfc);
+    SCALAR_MAPPER (erfcx, octave::math::erfcx);
+    SCALAR_MAPPER (erfi, octave::math::erfi);
+    SCALAR_MAPPER (dawson, octave::math::dawson);
+    SCALAR_MAPPER (ceil, octave::math::ceil);
+    SCALAR_MAPPER (conj, std::conj);
+    SCALAR_MAPPER (cos, std::cos);
+    SCALAR_MAPPER (cosh, std::cosh);
+    SCALAR_MAPPER (exp, std::exp);
+    SCALAR_MAPPER (expm1, octave::math::expm1);
+    SCALAR_MAPPER (fix, octave::math::fix);
+    SCALAR_MAPPER (floor, octave::math::floor);
+    SCALAR_MAPPER (imag, std::imag);
+    SCALAR_MAPPER (log, std::log);
+    SCALAR_MAPPER (log2, octave::math::log2);
+    SCALAR_MAPPER (log10, std::log10);
+    SCALAR_MAPPER (log1p, octave::math::log1p);
+    SCALAR_MAPPER (real, std::real);
+    SCALAR_MAPPER (round, octave::math::round);
+    SCALAR_MAPPER (roundb, octave::math::roundb);
+    SCALAR_MAPPER (signum, octave::math::signum);
+    SCALAR_MAPPER (sin, std::sin);
+    SCALAR_MAPPER (sinh, std::sinh);
+    SCALAR_MAPPER (sqrt, std::sqrt);
+    SCALAR_MAPPER (tan, std::tan);
+    SCALAR_MAPPER (tanh, std::tanh);
+    SCALAR_MAPPER (isfinite, octave::math::finite);
+    SCALAR_MAPPER (isinf, octave::math::isinf);
+    SCALAR_MAPPER (isna, octave::math::is_NA);
+    SCALAR_MAPPER (isnan, octave::math::isnan);
 
     default:
       return octave_base_value::map (umap);
     }
 }
+
