@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2008-2015 Jaroslav Hajek
+Copyright (C) 2008-2016 Jaroslav Hajek
 
 This file is part of Octave.
 
@@ -20,6 +20,10 @@ along with Octave; see the file COPYING.  If not, see
 
 */
 
+#if defined (HAVE_CONFIG_H)
+#  include "config.h"
+#endif
+
 #define LINCLUDE "ov-re-diag.h"
 #define RINCLUDE "ov-re-mat.h"
 
