@@ -1,4 +1,4 @@
-## Copyright (C) 2013-2015 Rik Wehbring
+## Copyright (C) 2013-2016 Rik Wehbring
 ##
 ## This file is part of Octave.
 ##
@@ -17,7 +17,7 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} atan2d (@var{y}, @var{x})
+## @deftypefn {} {} atan2d (@var{y}, @var{x})
 ## Compute atan2 (@var{y} / @var{x}) in degrees for corresponding elements
 ## from @var{y} and @var{x}.
 ## @seealso{tand, atan2}
