@@ -1,5 +1,5 @@
-## Copyright (C) 2008-2015 John W. Eaton
-## Copyright (C) 2013-2015 Carnë Draug
+## Copyright (C) 2008-2016 John W. Eaton
+## Copyright (C) 2013-2016 Carnë Draug
 ##
 ## This file is part of Octave.
 ##
@@ -17,9 +17,9 @@
 ## along with Octave; see the file COPYING.  If not, see
 ## <http://www.gnu.org/licenses/>.
 
-## This function does all the work of imwrite. It exists here as private
+## This function does all the work of imwrite.  It exists here as private
 ## function so that imwrite can use other functions if imformats is
-## configured to. It is also needed so that imformats can create a
+## configured to.  It is also needed so that imformats can create a
 ## function handle for it.
 
 function __imwrite__ (img, varargin)
@@ -46,7 +46,8 @@ function __imwrite__ (img, varargin)
                     "quality",   75,
                     "delaytime", ones (1, size (img, 4)) *500, # 0.5 seconds
                     "loopcount", 0, ## this is actually Inf
-                    "alpha",     cast ([], class (img)));
+                    "alpha",     cast ([], class (img)),
+                    "compression", "none");
 
   for idx = 1:2:numel (param_list)
 
@@ -67,6 +68,19 @@ function __imwrite__ (img, varargin)
                  param_list{idx});
         endif
 
+      case "compression"
+        options.compression = param_list{idx+1};
+        if (! ischar (options.compression))
+          error ("imwrite: value for %s option must be a string",
+                 param_list{idx});
+        endif
+        options.compression = tolower (options.compression);
+        if (! any (strcmp (options.compression, {"none", "bzip", "fax3", ...
+                                                 "fax4", "jpeg", "lzw", ...
+                                                 "rle", "deflate"})))
+          error ("imwrite: invalid compression `%s'", options.compression);
+        endif
+
       case "delaytime"
         options.delaytime = param_list{idx+1};
         if (! isnumeric (options.delaytime))
@@ -100,7 +114,7 @@ function __imwrite__ (img, varargin)
                             {"donotspecify", "leaveinplace", ...
                              "restorebg", "restoreprevious"});
         if (any (! matches))
-          error ("imwrite: unknow method %s for option %s",
+          error ("imwrite: unknown method %s for option %s",
                  options.disposalmethod{find (! matches, 1)},
                  param_list{idx});
         endif
@@ -120,19 +134,19 @@ function __imwrite__ (img, varargin)
           error ("imwrite: value for %s must be Inf or between 0 and 65535",
                  param_list{idx});
         endif
-        ## Graphics Magick is a bit weird here. A value of 0 will be an
+        ## Graphics Magick is a bit weird here.  A value of 0 will be an
         ## infinite loop, a value of 1, will really be no loop, while a
         ## value of 2 or more will be that number of loops (checked
-        ## with GNOME image viewer). This means that there is no way
-        ## to make it loop only once. See
+        ## with GNOME image viewer).  This means that there is no way
+        ## to make it loop only once.  See
         ## https://sourceforge.net/p/graphicsmagick/bugs/249/
         ## There is also the problem of setting this when there is only
-        ## a single frame. See
+        ## a single frame.  See
         ## https://sourceforge.net/p/graphicsmagick/bugs/248/
         if (isinf (options.loopcount))
           options.loopcount = 0;
         elseif (options.loopcount == 0 || options.loopcount == 1)
-          options.loopcount++;
+          options.loopcount += 1;
         endif
         options.loopcount = floor (options.loopcount);
 
@@ -175,12 +189,12 @@ function __imwrite__ (img, varargin)
       required_colors = max (img(:));
     endif
     if (nColors < required_colors)
-      warning ("imwrite: MAP has not enough colors. Filling with black");
+      warning ("imwrite: MAP has not enough colors.  Filling with black");
       map(nColors+1:required_colors,:) = 0;
     endif
 
     ## If the image is floating point, then we convert it to integer (makes
-    ## it easier in __magick_write__ since it only handles integers. Also,
+    ## it easier in __magick_write__ since it only handles integers.  Also,
     ## if it's floating point, it has an offset of 1
     if (isfloat (img))
       if (rows (map) <= 256)
