@@ -1,4 +1,4 @@
-## Copyright (C) 1999-2015 Kai Habel
+## Copyright (C) 1999-2016 Kai Habel
 ##
 ## This file is part of Octave.
 ##
@@ -17,8 +17,8 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {@var{map} =} white ()
-## @deftypefnx {Function File} {@var{map} =} white (@var{n})
+## @deftypefn  {} {@var{map} =} white ()
+## @deftypefnx {} {@var{map} =} white (@var{n})
 ## Create color colormap.  This colormap is completely white.
 ##
 ## The argument @var{n} must be a scalar.
@@ -28,9 +28,6 @@
 
 ## Author:  Kai Habel <kai.habel@gmx.de>
 
-## PKG_ADD: colormap ("register", "white");
-## PKG_DEL: colormap ("unregister", "white");
-
 function map = white (n = rows (colormap ()))
 
   if (nargin > 1)
@@ -45,8 +42,9 @@ endfunction
 
 
 %!demo
-%! ## Show the 'white' colormap as an image
-%! image (1:64, linspace (0, 1, 64), repmat ((1:64)', 1, 64));
-%! axis ([1, 64, 0, 1], "ticy", "xy");
-%! colormap (white (64));
-
+%! ## Show the 'white' colormap profile and as an image
+%! cmap = white (256);
+%! subplot (2, 1, 1);
+%!  rgbplot (cmap, "composite");
+%! subplot (2, 1, 2);
+%!  rgbplot (cmap);
