@@ -1,4 +1,4 @@
-## Copyright (C) 1996-2015 John W. Eaton
+## Copyright (C) 1996-2016 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,7 +17,7 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} __axis_label__ (@var{caller}, @var{h}, @var{txt}, @dots{})
+## @deftypefn {} {} __axis_label__ (@var{caller}, @var{h}, @var{txt}, @dots{})
 ## Undocumented internal function.
 ## @end deftypefn
 
@@ -30,14 +30,26 @@ function retval = __axis_label__ (hax, caller, txt, varargin)
   set (h, "fontangle", get (hax, "fontangle"),
           "fontname", get (hax, "fontname"),
           "fontunits", get (hax, "fontunits"),   # must precede fontsize
-          "fontsize", get (hax, "fontsize"),
+          "fontsize", get (hax, "LabelFontSizeMultiplier") *
+                      get (hax, "fontsize"),
           "fontweight", get (hax, "fontweight"),
           "string", txt,
           varargin{:});
 
+  ## FIXME: It would be better to delete only the listener that [xyz]label
+  ##        installed.  But this didn't work, so instead it deletes all
+  ##        listener's on the [xyz]color property.
+  dellistener (hax, [caller(1) "color"]);
+  addlistener (hax, [caller(1) "color"], {@cb_color, h, caller(1)});
+
   if (nargout > 0)
     retval = h;
   endif
 
 endfunction
 
+## Callback to update label color when axes color is changed
+function cb_color (hax, ~, hlabel, axis2label)
+  set (hlabel, "color", get (hax, [axis2label "color"]));
+endfunction
+
