@@ -1,5 +1,5 @@
-## Copyright (C) 2013-2015 Carl Osterwisch
-## Copyright (C) 2007-2015 John W. Eaton
+## Copyright (C) 2013-2016 Carl Osterwisch
+## Copyright (C) 2007-2016 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -18,7 +18,7 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {@var{rgb} =} __next_line_color__ (@var{reset})
+## @deftypefn {} {@var{rgb} =} __next_line_color__ (@var{reset})
 ## Undocumented internal function.
 ## @end deftypefn
 
@@ -27,29 +27,38 @@
 ## Author: Carl Osterwisch
 ## Author: jwe
 
-function rgb = __next_line_color__ (reset)
+function rgb = __next_line_color__ ()
 
-  persistent reset_colors = true;
+  ca = gca ();
 
-  if (nargin == 1)
-    ## Indicates whether the next call will increment or not
-    reset_colors = reset;
-  else
-    ## Find and return the next line color
-    ca = gca ();
-    colororder = get (ca, "colororder");
-    if (reset_colors)
-      color_index = 1;
-      reset_colors = false;
-    else
-      ## Executed when "hold all" is active
-      n_kids = length (get (ca, "children"));
-      n_colors = rows (colororder);
-      color_index = mod (n_kids, n_colors) + 1;
-    endif
-    rgb = colororder(color_index,:);
+  colororder = get (ca, "colororder");
+  if (isempty (colororder))
+    rgb = [0 0 0];   # black
+    return;
   endif
 
+  color_idx = fix (get (ca, "colororderindex"));
+  num_colors = rows (colororder);
+  color_idx = mod (color_idx, num_colors);
+  if (color_idx == 0)
+    color_idx = num_colors;
+  elseif (color_idx < 0)
+    color_idx = 1;
+  endif
+
+  rgb = colororder(color_idx, :);
+
+  if (++color_idx > num_colors)
+    color_idx = mod (color_idx, num_colors);
+    if (color_idx == 0)
+      color_idx = 1;
+    endif
+    ## Rollover through all colors also switches to next linestyle.
+    style_idx = fix (get (ca, "linestyleorderindex"));
+    set (ca, "linestyleorderindex", ++style_idx);
+  endif
+  set (ca, "colororderindex", color_idx);
+
 endfunction
 
 
@@ -59,13 +68,13 @@ endfunction
 %!   hax = axes ();
 %!   set (hax, "colororder", [1 0 0; 0 1 0; 0 0 1]);
 %!   hold on;
-%!   h = plot (1:5,1:5,'o', 1:4,1:4, "x", 1:3,1:3, "d");
+%!   h = plot (1:2,1:2,"o", 2:3,2:3,"x", 3:4,3:4,"d");
 %!   assert (get (h, "color"), {[1 0 0]; [0 1 0]; [0 0 1]});
 %!   cla (hax);
-%!   hold all;
-%!   h1 = plot (1:5,1:5,'o');
-%!   h2 = plot (1:4,1:4, "x");
-%!   h3 = plot (1:3,1:3, "d");
+%!   hold on;
+%!   h1 = plot (1:2,1:2, "o");
+%!   h2 = plot (2:3,2:3, "x");
+%!   h3 = plot (3:4,3:4, "d");
 %!   assert (get ([h1;h2;h3], "color"), {[1 0 0]; [0 1 0]; [0 0 1]});
 %! unwind_protect_cleanup
 %!   close (hf);
