@@ -1,4 +1,4 @@
-## Copyright (C) 2008-2015 VZLU Prague, a.s., Czech Republic
+## Copyright (C) 2008-2016 VZLU Prague, a.s., Czech Republic
 ##
 ## This file is part of Octave.
 ##
@@ -17,8 +17,8 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {ppd =} ppder (pp)
-## @deftypefnx {Function File} {ppd =} ppder (pp, m)
+## @deftypefn  {} {ppd =} ppder (pp)
+## @deftypefnx {} {ppd =} ppder (pp, m)
 ## Compute the piecewise @var{m}-th derivative of a piecewise polynomial
 ## struct @var{pp}.
 ##
@@ -49,6 +49,7 @@ function ppd = ppder (pp, m = 1)
   endif
 
   ppd = mkpp (x, pd, d);
+
 endfunction
 
 
