@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2012-2015 John W. Eaton
+Copyright (C) 2012-2016 John W. Eaton
 
 This file is part of Octave.
 
@@ -20,13 +20,19 @@ along with Octave; see the file COPYING.  If not, see
 
 */
 
-#ifdef __cplusplus
-#include <new>
+#if ! defined (octave_display_available_h)
+#define octave_display_available_h 1
+
+#if defined (__cplusplus)
+#  include <new>
 extern "C" {
 #endif
 
 extern const char *display_available (int *dpy_avail);
 
-#ifdef __cplusplus
+#if defined (__cplusplus)
 }
 #endif
+
+#endif
+
