@@ -1,6 +1,6 @@
-#!/bin/sh
+#! /bin/sh
 
-# Copyright (C) 2006-2015 David Bateman
+# Copyright (C) 2006-2016 David Bateman
 #
 # This file is part of Octave.
 #
@@ -21,15 +21,15 @@
 # Some tests are commented out because they are known to be broken!
 # Search for "# fails"
 
-# ./build_sparse_tests.sh preset
+# ./build-sparse-tests.sh preset
 #    creates sparse.tst with preset tests.
 #    Use "test sparse.tst" from octave to run the tests.
 #
-# ./build_sparse_tests.sh random
+# ./build-sparse-tests.sh random
 #    Creates sprandom.tst with randomly generated matrices.
 #    Use "test sprandom.tst" from octave to run the tests.
 
-# build_sparse_tests.sh generates tests for real and complex sparse matrices.
+# build-sparse-tests.sh generates tests for real and complex sparse matrices.
 # Also, we want to run both fixed tests with known outputs (quick tests)
 # and longer tests with unknown outputs (thorough tests).  This requires
 # two sets of tests -- one which uses preset matrices and another which
@@ -110,20 +110,14 @@ case $1 in
     random) preset=false ;;
     preset) preset=true ;;
     '') preset=true ;;
-    *) echo "build_sparse_tests.sh random|preset" && exit 1 ;;
+    *) echo "build-sparse-tests.sh random|preset" && exit 1 ;;
 esac
 
-if $preset; then
-    TESTS=sparse.tst
-else
-    TESTS=sprandom.tst
-fi
-
 # create initial file
-cat >$TESTS <<EOF
+cat <<EOF
 ## !!! DO NOT EDIT !!!
 ## THIS IS AN AUTOMATICALLY GENERATED FILE
-## modify build_sparse_tests.sh to generate the tests you need.
+## modify build-sparse-tests.sh to generate the tests you need.
 EOF
 
 
@@ -134,7 +128,7 @@ EOF
 # Section separator
 
 gen_section() {
-cat >>$TESTS <<EOF
+cat <<EOF
 
 # ==============================================================
 
@@ -149,7 +143,7 @@ EOF
 # If a sparse operation yields zeros, then those elements
 # of the returned sparse matrix should be eaten.
 gen_eat_zeros() {
-cat >>$TESTS <<EOF
+cat <<EOF
 %% Make sure newly introduced zeros get eaten
 %!assert (nnz (sparse ([bf,bf,1]).^realmax), 1)
 %!assert (nnz (sparse ([1,bf,bf]).^realmax), 1)
@@ -171,7 +165,7 @@ EOF
 }
 
 gen_specific() {
-cat >>$TESTS <<EOF
+cat <<EOF
 
 %!test # segfault test from edd@debian.org
 %! n = 510;
@@ -180,7 +174,7 @@ cat >>$TESTS <<EOF
 %% segfault tests from Fabian@isas-berlin.de
 %% Note that the last four do not fail, but rather give a warning
 %% of a singular matrix, which is consistent with the full matrix
-%% behaviour.  They are therefore disabled.
+%% behavior.  They are therefore disabled.
 %!testif HAVE_UMFPACK
 %! assert (inv (sparse ([1,1;1,1+i])), sparse ([1-1i,1i;1i,-1i]), 10*eps);
 %#!error inv ( sparse ([1,1;1,1]  ) );
@@ -190,7 +184,7 @@ cat >>$TESTS <<EOF
 
 %% error handling in constructor
 %!error sparse (1,[2,3],[1,2,3])
-%!error sparse ([1,1],[1,1],[1,2],3,3,"bogus")
+%!error sparse ([1,1],[1,1],[1,2],3,3,"invalid")
 %!error sparse ([1,3],[1,-4],[3,5],2,2)
 %!error sparse ([1,3],[1,-4],[3,5i],2,2)
 %!error sparse (-1,-1,1)
@@ -202,12 +196,12 @@ gen_specific_tests() {
     gen_section
     gen_specific
     gen_section
-    echo '%!shared bf' >> $TESTS
-    echo '%!test bf=realmin;' >> $TESTS
+    echo '%!shared bf'
+    echo '%!test bf=realmin;'
     gen_eat_zeros
-    echo '%!test bf=realmin+realmin*1i;' >> $TESTS
+    echo '%!test bf=realmin+realmin*1i;'
     gen_eat_zeros
-    cat >>$TESTS <<EOF
+    cat <<EOF
 %!assert (nnz (sparse ([-1,realmin,realmin]).^1.5), 1)
 %!assert (nnz (sparse ([-1,realmin,realmin,1]).^1.5), 2)
 
@@ -231,7 +225,7 @@ EOF
 
 gen_function() {
     if $preset; then
-        cat >>$TESTS <<EOF
+        cat <<EOF
 ##
 ## test_sparse
 ##
@@ -243,7 +237,7 @@ endfunction
 
 EOF
     else
-        cat >>$TESTS <<EOF
+        cat <<EOF
 ##
 ## test_sprandom
 ##
@@ -255,7 +249,7 @@ EOF
 ##  end
 ##  The test log is appended to sprandomtest.log
 function [passes,total] = test_sprandom
-  warning ("untested --- fix the source in build_sparse_tests.sh");
+  warning ("untested --- fix the source in build-sparse-tests.sh");
   disp ("appending test output to sprandomtest.log");
   fid = fopen ("sprandomtest.log", "at");
   test ("sprandom.tst", "normal", fid);
@@ -274,7 +268,7 @@ EOF
 
 # test ordered comparisons: uses as,af,bs,bf
 gen_ordering_tests() {
-    cat >>$TESTS <<EOF
+    cat <<EOF
 %% real values can be ordered (uses as,af)
 %!assert (as<=bf, sparse (af<=bf))
 %!assert (bf<=as, sparse (bf<=af))
@@ -292,7 +286,7 @@ EOF
 }
 
 gen_sparsesparse_ordering_tests() {
-    cat >>$TESTS <<EOF
+    cat <<EOF
 %!assert (as<=bs, sparse (af<=bf))
 %!assert (as>=bs, sparse (af>=bf))
 %!assert (as<bs, sparse (af<bf))
@@ -302,7 +296,7 @@ EOF
 
 # test element-wise binary operations: uses as,af,bs,bf,scalar
 gen_elementop_tests() {
-    cat >>$TESTS <<EOF
+    cat <<EOF
 %% Elementwise binary tests (uses as,af,bs,bf,scalar)
 %!assert (as==bs, sparse (af==bf))
 %!assert (bf==as, sparse (bf==af))
@@ -326,13 +320,13 @@ gen_elementop_tests() {
 %! sv = as.^bf;
 %! fv = af.^bf;
 %! idx = find (af!=0);
-%! assert (sv(:)(idx), sparse (fv(:)(idx)), 100*eps)
+%! assert (sv(:)(idx), sparse (fv(:)(idx)), 100*eps);
 
 EOF
 }
 
 gen_sparsesparse_elementop_tests() {
-    cat >>$TESTS <<EOF
+    cat <<EOF
 %!assert (as==bs, sparse (af==bf))
 %!assert (as!=bs, sparse (af!=bf))
 %!assert (as+bs, sparse (af+bf))
@@ -343,14 +337,14 @@ gen_sparsesparse_elementop_tests() {
 %! sv = as.^bs;
 %! fv = af.^bf;
 %! idx = find (af!=0);
-%! assert(sv(:)(idx), sparse (fv(:)(idx)), 100*eps)
+%! assert(sv(:)(idx), sparse (fv(:)(idx)), 100*eps);
 
 EOF
 }
 
 # test matrix-matrix left and right division: uses as,af,bs,bf
 gen_divop_tests() {
-    cat >>$TESTS <<EOF
+    cat <<EOF
 %% Matrix-matrix operators (uses af,as,bs,bf)
 %!assert (as/bf, af/bf, 100*eps)
 %!assert (af/bs, af/bf, 100*eps)
@@ -364,7 +358,7 @@ EOF
 
 # test matrix-matrix left and right division: uses as,af,bs,bf
 gen_square_divop_tests() {
-    cat >>$TESTS <<EOF
+    cat <<EOF
 %% Matrix-matrix operators (uses af,as,bs,bf)
 %!assert (as/bf, af/bf, 100*eps)
 %!assert (af/bs, af/bf, 100*eps)
@@ -378,7 +372,7 @@ EOF
 
 # test matrix-matrix operations: uses as,af,bs,bf
 gen_matrixop_tests() {
-    cat >>$TESTS <<EOF
+    cat <<EOF
 %% Matrix-matrix operators (uses af,as,bs,bf)
 %!assert (as*bf', af*bf')
 %!assert (af*bs', af*bf')
@@ -389,7 +383,7 @@ EOF
 
 # test diagonal operations
 gen_matrixdiag_tests() {
-    cat >>$TESTS <<EOF
+    cat <<EOF
 %% Matrix diagonal tests (uses af,as,bf,bs)
 %!assert (diag (as), sparse (diag (af)))
 %!assert (diag (bs), sparse (diag (bf)))
@@ -414,7 +408,7 @@ EOF
 
 # test matrix reshape operations
 gen_matrixreshape_tests() {
-    cat >>$TESTS <<EOF
+    cat <<EOF
 %% Matrix diagonal tests (uses af,as,bf,bs)
 %!assert (reshape (as,1,prod(size(as))), sparse (reshape (af,1,prod(size(af)))))
 %!assert (reshape (as,prod(size(as)),1), sparse (reshape (af,prod(size(af)),1)))
@@ -428,11 +422,11 @@ EOF
 
 # test mapper matrix operations: uses as,af
 print_mapper_test() {
-echo "%!assert ($1(as), sparse ($1(af)))" >>$TESTS
+echo "%!assert ($1(as), sparse ($1(af)))"
 }
 
 print_real_mapper_test() {
-    cat >>$TESTS <<EOF
+    cat <<EOF
 %!test
 %! wn2s = warning ("query", "Octave:num-to-str");
 %! warning ("off", "Octave:num-to-str");
@@ -449,7 +443,7 @@ EOF
 }
 
 gen_mapper_tests() {
-echo "%% Unary matrix tests (uses af,as)">>$TESTS
+echo "%% Unary matrix tests (uses af,as)"
 print_mapper_test abs
 print_mapper_test acos
 print_mapper_test acosh
@@ -483,7 +477,7 @@ print_mapper_test tan
 print_mapper_test tanh
 
 # Specific tests for certain mapper functions
-    cat >>$TESTS <<EOF
+    cat <<EOF
 %!assert (issparse (abs (as))  && isreal (abs (as)))
 %!assert (issparse (real (as)) && isreal (real (as)))
 %!assert (issparse (imag (as)) && isreal (imag (as)))
@@ -492,7 +486,7 @@ EOF
 }
 
 gen_real_mapper_tests() {
-echo "%% Unary matrix tests (uses af,as)">>$TESTS
+echo "%% Unary matrix tests (uses af,as)"
 print_real_mapper_test erf 1
 print_real_mapper_test erfc 1
 #print_real_mapper_test gamma 1
@@ -511,7 +505,7 @@ print_real_mapper_test isxdigit 0
 #print_real_mapper_test gammaln 1
 
 # Specific tests for certain mapper functions
-    cat >>$TESTS <<EOF
+    cat <<EOF
 
 %!test
 %! wn2s = warning ("query", "Octave:num-to-str");
@@ -528,7 +522,7 @@ EOF
 
 # test matrix operations: uses as,af
 gen_unaryop_tests() {
-    cat >>$TESTS <<EOF
+    cat <<EOF
 %% Unary matrix tests (uses af,as)
 %!assert (issparse (as))
 %!assert (!issparse (af))
@@ -577,10 +571,10 @@ gen_unaryop_tests() {
 %!assert (issparse (as'))
 %!assert (issparse (-as))
 %!assert (!as, sparse (!af))
-%!assert (as.', sparse (af.'));
-%!assert (as',  sparse (af'));
-%!assert (-as, sparse (-af));
-%!assert (!as, sparse (!af));
+%!assert (as.', sparse (af.'))
+%!assert (as',  sparse (af'))
+%!assert (-as, sparse (-af))
+%!assert (!as, sparse (!af))
 %!error [i,j] = size (af);as(i-1,j+1);
 %!error [i,j] = size (af);as(i+1,j-1);
 %!test
@@ -589,8 +583,8 @@ gen_unaryop_tests() {
 %! assert (Is, If);
 %! assert (Js, Jf);
 %! assert (Vs, Vf);
-%!error as(0,1);
-%!error as(1,0);
+%!error as(0,1)
+%!error as(1,0)
 %!assert (find (as), find (af))
 %!test
 %! [i,j,v] = find (as);
@@ -601,28 +595,28 @@ gen_unaryop_tests() {
 %! [i,j,v,m,n] = find (as);
 %! x = sparse (i,j,v,m,n);
 %! assert (x, as);
-%!assert (issparse (horzcat (as,as)));
-%!assert (issparse (vertcat (as,as)));
-%!assert (issparse (cat (1,as,as)));
-%!assert (issparse (cat (2,as,as)));
-%!assert (issparse ([as,as]));
-%!assert (issparse ([as;as]));
-%!assert (horzcat (as,as), sparse ([af,af]));
-%!assert (vertcat (as,as), sparse ([af;af]));
-%!assert (horzcat (as,as,as), sparse ([af,af,af]));
-%!assert (vertcat (as,as,as), sparse ([af;af;af]));
-%!assert ([as,as], sparse ([af,af]));
-%!assert ([as;as], sparse ([af;af]));
-%!assert ([as,as,as], sparse ([af,af,af]));
-%!assert ([as;as;as], sparse ([af;af;af]));
-%!assert (cat (2,as,as), sparse ([af,af]));
-%!assert (cat (1,as,as), sparse ([af;af]));
-%!assert (cat (2,as,as,as), sparse ([af,af,af]));
-%!assert (cat (1,as,as,as), sparse ([af;af;af]));
-%!assert (issparse ([as,af]));
-%!assert (issparse ([af,as]));
-%!assert ([as,af], sparse ([af,af]));
-%!assert ([as;af], sparse ([af;af]));
+%!assert (issparse (horzcat (as,as)))
+%!assert (issparse (vertcat (as,as)))
+%!assert (issparse (cat (1,as,as)))
+%!assert (issparse (cat (2,as,as)))
+%!assert (issparse ([as,as]))
+%!assert (issparse ([as;as]))
+%!assert (horzcat (as,as), sparse ([af,af]))
+%!assert (vertcat (as,as), sparse ([af;af]))
+%!assert (horzcat (as,as,as), sparse ([af,af,af]))
+%!assert (vertcat (as,as,as), sparse ([af;af;af]))
+%!assert ([as,as], sparse ([af,af]))
+%!assert ([as;as], sparse ([af;af]))
+%!assert ([as,as,as], sparse ([af,af,af]))
+%!assert ([as;as;as], sparse ([af;af;af]))
+%!assert (cat (2,as,as), sparse ([af,af]))
+%!assert (cat (1,as,as), sparse ([af;af]))
+%!assert (cat (2,as,as,as), sparse ([af,af,af]))
+%!assert (cat (1,as,as,as), sparse ([af;af;af]))
+%!assert (issparse ([as,af]))
+%!assert (issparse ([af,as]))
+%!assert ([as,af], sparse ([af,af]))
+%!assert ([as;af], sparse ([af;af]))
 
 EOF
 }
@@ -632,9 +626,9 @@ gen_square_tests() {
 # The \ and / operator tests on square matrices
     gen_square_divop_tests
 
-    cat >>$TESTS <<EOF
+    cat <<EOF
 %!testif HAVE_UMFPACK
-%! assert(det(bs+speye(size(bs))), det(bf+eye(size(bf))), 100*eps*abs(det(bf+eye(size(bf)))))
+%! assert(det(bs+speye(size(bs))), det(bf+eye(size(bf))), 100*eps*abs(det(bf+eye(size(bf)))));
 
 %!testif HAVE_UMFPACK
 %! [l,u] = lu (sparse ([1,1;1,1]));
@@ -688,16 +682,16 @@ gen_square_tests() {
 %!testif HAVE_UMFPACK   # inverse
 %! assert (inv (bs)*bs, sparse (eye (rows (bs))), 1e-10);
 
-%!assert (bf\as', bf\af', 100*eps);
-%!assert (bs\af', bf\af', 100*eps);
-%!assert (bs\as', sparse (bf\af'), 100*eps);
+%!assert (bf\as', bf\af', 100*eps)
+%!assert (bs\af', bf\af', 100*eps)
+%!assert (bs\as', sparse (bf\af'), 100*eps)
 
 EOF
 }
 
 # Cholesky tests
 gen_cholesky_tests() {
-    cat >>$TESTS <<EOF
+    cat <<EOF
 %!testif HAVE_CHOLMOD
 %! assert (chol (bs)'*chol (bs), bs, 1e-10);
 %!testif HAVE_CHOLMOD
@@ -726,19 +720,19 @@ EOF
 
 # test scalar operations: uses af and real scalar bf; modifies as,bf,bs
 gen_scalar_tests() {
-    echo '%!test as = sparse (af);' >> $TESTS
-    echo '%!test bs = bf;' >> $TESTS
+    echo '%!test as = sparse (af);'
+    echo '%!test bs = bf;'
     gen_elementop_tests
     gen_ordering_tests
-    echo '%!test bf = bf+1i;' >>$TESTS
-    echo '%!test bs = bf;' >> $TESTS
+    echo '%!test bf = bf+1i;'
+    echo '%!test bs = bf;'
     gen_elementop_tests
 }
 
 # test matrix operations: uses af and bf; modifies as,bs
 gen_rectangular_tests() {
-    echo '%!test as = sparse(af);' >> $TESTS
-    echo '%!test bs = sparse(bf);' >>$TESTS
+    echo '%!test as = sparse(af);'
+    echo '%!test bs = sparse(bf);'
     gen_mapper_tests
     gen_real_mapper_tests
     gen_unaryop_tests
@@ -748,7 +742,7 @@ gen_rectangular_tests() {
     # gen_divop_tests # Disable rectangular \ and / for now
     gen_matrixdiag_tests
     gen_matrixreshape_tests
-    cat >>$TESTS <<EOF
+    cat <<EOF
 %!testif HAVE_UMFPACK   # permuted LU
 %! [L,U] = lu (bs);
 %! assert (L*U, bs, 1e-10);
@@ -797,7 +791,7 @@ EOF
 # sparse assembly tests
 
 gen_assembly_tests() {
-cat >>$TESTS <<EOF
+cat <<EOF
 %%Assembly tests
 %!test
 %! m = max ([m;r(:)]);
@@ -838,21 +832,21 @@ EOF
 # sparse selection tests
 
 gen_scalar_select_tests () {
-    cat >>$TESTS <<EOF
+    cat <<EOF
 %!assert (sparse (42)([1,1]), sparse ([42,42]))
 %!assert (sparse (42*1i)([1,1]), sparse ([42,42].*1i))
 EOF
 }
 
 gen_select_tests() {
-    cat >>$TESTS <<EOF
+    cat <<EOF
 %!test as = sparse (af);
 
 %% Point tests
 %!test idx = ridx(:) + rows (as) * (cidx (:)-1);
 %!assert (sparse (as(idx)), sparse (af(idx)))
-%!assert (as(idx), sparse (af(idx)));
-%!assert (as(idx'), sparse (af(idx')));
+%!assert (as(idx), sparse (af(idx)))
+%!assert (as(idx'), sparse (af(idx')))
 %!assert (as(flipud (idx(:))), sparse (af(flipud (idx(:)))))
 %!assert (as([idx,idx]), sparse (af([idx,idx])))
 %!assert (as(reshape ([idx;idx], [1,length(idx),2])), sparse(af(reshape ([idx;idx], [1,length(idx),2]))))
@@ -870,7 +864,7 @@ gen_select_tests() {
 %!assert (full (as(:,[1,1])), af(:,[1,1]))
 %!test
 %! [i,j,v] = find (as);
-%! assert (as(i(1),j(1))([1,1]), sparse ([v(1), v(1)]))
+%! assert (as(i(1),j(1))([1,1]), sparse ([v(1), v(1)]));
 
 %% Assignment test
 %!test
@@ -912,7 +906,7 @@ EOF
 # sparse save and load tests
 
 gen_save_tests() {
-    cat >>$TESTS <<EOF
+    cat <<EOF
 %!test # save ascii
 %! savefile = tempname ();
 %! as_save = as;
@@ -937,7 +931,7 @@ gen_save_tests() {
 %! load (savefile, "as_save");
 %! unlink (savefile);
 %! assert (as_save, sparse (af));
-## FIXME: We should skip (or mark as an expected failure) the test for
+## FIXME: We should skip (or mark as a known bug) the test for
 ## saving sparse matrices to MAT files when using 64-bit indexing since
 ## that is not implemented yet.
 %!test # save matlab
@@ -957,14 +951,14 @@ EOF
 gen_solver_tests() {
 
 if $preset; then
-  cat >>$TESTS <<EOF
+  cat <<EOF
 %! n=8;
 %! lf=diag (1:n); lf(n-1,1)=0.5*alpha; lf(n,2)=0.25*alpha; ls=sparse (lf);
 %! uf=diag (1:n); uf(1,n-1)=2*alpha; uf(2,n)=alpha; us=sparse (uf);
 %! ts=spdiags (ones (n,3),-1:1,n,n) + diag (1:n); tf = full (ts);
 EOF
 else
-  cat >>$TESTS <<EOF
+  cat <<EOF
 %! n = floor (lognrnd (8,2)+1)';
 %! ls = tril (sprandn (8,8,0.2),-1).*alpha + n*speye (8); lf = full (ls);
 %! us = triu (sprandn (8,8,0.2),1).*alpha + n*speye (8); uf = full (us);
@@ -972,7 +966,7 @@ else
 EOF
 fi
 
-cat >>$TESTS <<EOF
+cat <<EOF
 %! df = diag (1:n).* alpha; ds = sparse (df);
 %! pdf = df(randperm (n), randperm (n));
 %! pds = sparse (pdf);
@@ -987,24 +981,24 @@ cat >>$TESTS <<EOF
 %! tcf = tf + tf'; tcs = sparse (tcf);
 %! xf = diag (1:n) + fliplr (diag (1:n)).*beta;
 %! xs = sparse (xf);
-%!assert (ds\xf, df\xf, 1e-10);
-%!assert (ds\xs, sparse (df\xf), 1e-10);
-%!assert (pds\xf, pdf\xf, 1e-10);
-%!assert (pds\xs, sparse (pdf\xf), 1e-10);
-%!assert (ls\xf, lf\xf, 1e-10);
-%!assert (sparse (ls\xs), sparse (lf\xf), 1e-10);
+%!assert (ds\xf, df\xf, 1e-10)
+%!assert (ds\xs, sparse (df\xf), 1e-10)
+%!assert (pds\xf, pdf\xf, 1e-10)
+%!assert (pds\xs, sparse (pdf\xf), 1e-10)
+%!assert (ls\xf, lf\xf, 1e-10)
+%!assert (sparse (ls\xs), sparse (lf\xf), 1e-10)
 %!testif HAVE_UMFPACK
 %! assert (pls\xf, plf\xf, 1e-10);
 %!testif HAVE_UMFPACK
 %! assert (sparse (pls\xs), sparse (plf\xf), 1e-10);
-%!assert (us\xf, uf\xf, 1e-10);
-%!assert (sparse (us\xs), sparse (uf\xf), 1e-10);
+%!assert (us\xf, uf\xf, 1e-10)
+%!assert (sparse (us\xs), sparse (uf\xf), 1e-10)
 %!testif HAVE_UMFPACK
 %! assert (pus\xf, puf\xf, 1e-10);
 %!testif HAVE_UMFPACK
 %! assert (sparse (pus\xs), sparse (puf\xf), 1e-10);
-%!assert (bs\xf, bf\xf, 1e-10);
-%!assert (sparse (bs\xs), sparse (bf\xf), 1e-10);
+%!assert (bs\xf, bf\xf, 1e-10)
+%!assert (sparse (bs\xs), sparse (bf\xf), 1e-10)
 %!testif HAVE_UMFPACK
 %! assert (cs\xf, cf\xf, 1e-10);
 %!testif HAVE_UMFPACK
@@ -1013,14 +1007,14 @@ cat >>$TESTS <<EOF
 %! assert (bcs\xf, bcf\xf, 1e-10);
 %!testif HAVE_UMFPACK
 %! assert (sparse (bcs\xs), sparse (bcf\xf), 1e-10);
-%!assert (ts\xf, tf\xf, 1e-10);
-%!assert (sparse (ts\xs), sparse (tf\xf), 1e-10);
-%!assert (tcs\xf, tcf\xf, 1e-10);
-%!assert (sparse (tcs\xs), sparse (tcf\xf), 1e-10);
+%!assert (ts\xf, tf\xf, 1e-10)
+%!assert (sparse (ts\xs), sparse (tf\xf), 1e-10)
+%!assert (tcs\xf, tcf\xf, 1e-10)
+%!assert (sparse (tcs\xs), sparse (tcf\xf), 1e-10)
 
 EOF
 
-cat >>$TESTS <<EOF
+cat <<EOF
 %% QR solver tests
 
 %!function f (a, sz, feps)
@@ -1075,34 +1069,34 @@ cat >>$TESTS <<EOF
 %!test
 %! us = alpha*[[speye(10,10);sparse(1,10)],[[1,1];sparse(9,2);[1,1]]];
 %!testif HAVE_UMFPACK
-%! assert (us*(us\xf), xf, 100*eps)
+%! assert (us*(us\xf), xf, 100*eps);
 %!testif HAVE_UMFPACK
-%! assert (us*(us\xs), xs, 100*eps)
+%! assert (us*(us\xs), xs, 100*eps);
 %!test
 %! pus = us(:,[2,1,3:12]);
 %!testif HAVE_UMFPACK
-%! assert (pus*(pus\xf), xf, 100*eps)
+%! assert (pus*(pus\xf), xf, 100*eps);
 %!testif HAVE_UMFPACK
-%! assert (pus*(pus\xs), xs, 100*eps)
+%! assert (pus*(pus\xs), xs, 100*eps);
 %!test
 %! us = alpha*[speye(11,9),[1;sparse(8,1);1;0]];
 %!testif HAVE_CXSPARSE
 %! [c,r] = qr (us, xf);
-%! assert (us\xf, r\c, 100*eps)
+%! assert (us\xf, r\c, 100*eps);
 %!testif HAVE_UMFPACK
 %! [c,r] = qr (us, xs);
 %! r = matrix_type (r, "Singular"); ## Force Matrix Type
-%! assert (us\xs, r\c, 100*eps)
+%! assert (us\xs, r\c, 100*eps);
 %!test
 %! pus = us(:,[1:8,10,9]);
 %!testif HAVE_UMFPACK
 %! [c,r] = qr (pus, xf);
 %! r = matrix_type (r, "Singular"); ## Force Matrix Type
-%! assert (pus\xf, r\c, 100*eps)
+%! assert (pus\xf, r\c, 100*eps);
 %!testif HAVE_UMFPACK
 %! [c,r] = qr (pus, xs);
 %! r = matrix_type (r, "Singular"); ## Force Matrix Type
-%! assert (pus\xs, r\c, 100*eps)
+%! assert (pus\xs, r\c, 100*eps);
 %!test
 %! ls = alpha*[speye(9,11);[1, sparse(1,8),1,0]];
 %! xf = beta * ones (10,2);
@@ -1119,21 +1113,21 @@ cat >>$TESTS <<EOF
 %! xs = speye (12,12);
 %!testif HAVE_UMFPACK
 %! [c,r] = qr (ls, xf);
-%! assert (ls\xf, r\c, 100*eps)
+%! assert (ls\xf, r\c, 100*eps);
 %!testif HAVE_UMFPACK
 %! [c,r] = qr (ls, xs);
 %! r = matrix_type (r, "Singular"); ## Force Matrix Type
-%! assert (ls\xs, r\c, 100*eps)
+%! assert (ls\xs, r\c, 100*eps);
 %!testif HAVE_CXSPARSE
 %! pls = ls(:,[1:8,10,9]);
 %!testif HAVE_UMFPACK
 %! [c,r] = qr (pls, xf);
 %! r = matrix_type (r, "Singular"); ## Force Matrix Type
-%! assert (pls\xf, r\c, 100*eps)
+%! assert (pls\xf, r\c, 100*eps);
 %!testif HAVE_UMFPACK
 %! [c,r] = qr (pls, xs);
 %! r = matrix_type (r, "Singular"); ## Force Matrix Type
-%! assert (pls\xs, r\c, 100*eps)
+%! assert (pls\xs, r\c, 100*eps);
 
 EOF
 }
@@ -1154,12 +1148,12 @@ if $preset; then
 fi
 
 # scalar operations
-echo '%!shared as,af,bs,bf' >> $TESTS
+echo '%!shared as,af,bs,bf'
 if $preset; then
-    echo '%!test af=[1+1i,2-1i,0,0;0,0,0,3+2i;0,0,0,4];' >> $TESTS
-    echo '%!test bf=3;' >>$TESTS
+    echo '%!test af=[1+1i,2-1i,0,0;0,0,0,3+2i;0,0,0,4];'
+    echo '%!test bf=3;'
 else
-    cat >>$TESTS <<EOF
+    cat <<EOF
 %!test
 %! % generate m,n from 1 to <5000
 %! m = floor (lognrnd (8,2)+1);
@@ -1175,10 +1169,10 @@ gen_section
 
 # rectangular operations
 if $preset; then
-    echo '%!test af=[1+1i,2-1i,0,0;0,0,0,3+2i;0,0,0,4];' >> $TESTS
-    echo '%!test bf=[0,1-1i,0,0;2+1i,0,0,0;3-1i,2+3i,0,0];' >> $TESTS
+    echo '%!test af=[1+1i,2-1i,0,0;0,0,0,3+2i;0,0,0,4];'
+    echo '%!test bf=[0,1-1i,0,0;2+1i,0,0,0;3-1i,2+3i,0,0];'
 else
-    cat >>$TESTS <<EOF
+    cat <<EOF
 %!test
 %! m = floor (lognrnd (8,2)+1);
 %! n = floor (lognrnd (8,2)+1);
@@ -1193,27 +1187,27 @@ gen_rectangular_tests
 gen_section
 gen_save_tests
 gen_section
-echo '%!test bf = real (bf);' >> $TESTS
+echo '%!test bf = real (bf);'
 gen_rectangular_tests
 gen_section
 gen_sparsesparse_ordering_tests
 gen_section
-echo '%!test af = real (af);' >> $TESTS
+echo '%!test af = real (af);'
 gen_rectangular_tests
 gen_section
 gen_save_tests
 gen_section
-echo '%!test bf = bf+1i*(bf!=0);' >> $TESTS
+echo '%!test bf = bf+1i*(bf!=0);'
 gen_rectangular_tests
 gen_section
 
 # square operations
 if $preset; then
-    echo '%!test af = [1+1i,2-1i,0,0;0,0,0,3+2i;0,0,0,4];' >> $TESTS
-    echo '%! as = sparse (af);' >> $TESTS
-    echo '%!test bf = [0,1-1i,0,0;2+1i,0,0,0;3-1i,2+3i,0,0];' >> $TESTS
+    echo '%!test af = [1+1i,2-1i,0,0;0,0,0,3+2i;0,0,0,4];'
+    echo '%! as = sparse (af);'
+    echo '%!test bf = [0,1-1i,0,0;2+1i,0,0,0;3-1i,2+3i,0,0];'
 else
-    cat >>$TESTS <<EOF
+    cat <<EOF
 %!test
 %! m = floor (lognrnd (8,2)+1);
 %! n = floor (lognrnd (8,2)+1);
@@ -1224,7 +1218,7 @@ else
 EOF
 fi
 
-cat >>$TESTS <<EOF
+cat <<EOF
 %!test ;# invertible matrix
 %! bf = af'*bf+max (abs ([af(:);bf(:)]))*sparse (eye (columns (as)));
 %! bs = sparse (bf);
@@ -1233,48 +1227,48 @@ EOF
 
 gen_square_tests
 gen_section
-echo '%!test bf = real (bf);' >> $TESTS
-echo '%! bs = sparse (bf);' >> $TESTS
+echo '%!test bf = real (bf);'
+echo '%! bs = sparse (bf);'
 gen_square_tests
 gen_section
-echo '%!test af = real (af);' >> $TESTS
-echo '%! as = sparse (af);' >> $TESTS
+echo '%!test af = real (af);'
+echo '%! as = sparse (af);'
 gen_square_tests
 gen_section
-echo '%!test bf = bf+1i*(bf!=0);' >> $TESTS
-echo '%! bs = sparse (bf);' >> $TESTS
+echo '%!test bf = bf+1i*(bf!=0);'
+echo '%! bs = sparse (bf);'
 gen_square_tests
 gen_section
 
 # cholesky tests
 if $preset; then
-  echo '%!test bf = [5,0,1+1i,0;0,5,0,1-2i;1-1i,0,5,0;0,1+2i,0,5];' >> $TESTS
-  echo '%! bs = sparse (bf);' >> $TESTS
+  echo '%!test bf = [5,0,1+1i,0;0,5,0,1-2i;1-1i,0,5,0;0,1+2i,0,5];'
+  echo '%! bs = sparse (bf);'
 else
-  echo '# This has a small chance of failing to create a positive definite matrix' >> $TESTS
-  echo '%!test n = floor (lognrnd (8,2)+1)' >> $TESTS
-  echo '%! bs = n*speye (n,n) + sprandn (n,n,0.3);' >> $TESTS
-  echo '%! bf = full (bs);' >> $TESTS
+  echo '# This has a small chance of failing to create a positive definite matrix'
+  echo '%!test n = floor (lognrnd (8,2)+1)'
+  echo '%! bs = n*speye (n,n) + sprandn (n,n,0.3);'
+  echo '%! bf = full (bs);'
 fi
 
 gen_cholesky_tests
 gen_section
-echo '%!test bf = real (bf);' >> $TESTS
-echo '%! bs = sparse (bf);' >> $TESTS
+echo '%!test bf = real (bf);'
+echo '%! bs = sparse (bf);'
 gen_cholesky_tests
 gen_section
 
 # assembly tests
-echo '%!shared r,c,m,n,fsum,funiq' >>$TESTS
+echo '%!shared r,c,m,n,fsum,funiq'
 if $use_preset; then
-    cat >>$TESTS <<EOF
+    cat <<EOF
 %!test
 %! r = [1,1,2,1,2,3];
 %! c = [2,1,1,1,2,1];
 %! m = n = 0;
 EOF
 else
-    cat >>$TESTS <<EOF
+    cat <<EOF
 %!test
 %! % generate m,n from 1 to <5000
 %! m = floor (lognrnd (8,2)+1);
@@ -1288,16 +1282,16 @@ gen_assembly_tests #includes real and complex tests
 gen_section
 
 # slicing tests
-echo '%!shared ridx,cidx,idx,as,af' >>$TESTS
+echo '%!shared ridx,cidx,idx,as,af'
 if $use_preset; then
-    cat >>$TESTS <<EOF
+    cat <<EOF
 %!test
 %! af = [1+1i,2-1i,0,0;0,0,0,3+2i;0,0,0,4];
 %! ridx = [1,3];
 %! cidx = [2,3];
 EOF
 else
-    cat >>$TESTS <<EOF
+    cat <<EOF
 %!test
 %! % generate m,n from 1 to <5000
 %! m = floor (lognrnd (8,2)+1);
@@ -1310,16 +1304,16 @@ EOF
 fi
 gen_scalar_select_tests
 gen_select_tests
-echo '%!test af = real (af);' >> $TESTS
+echo '%!test af = real (af);'
 gen_select_tests
 gen_section
-echo '%!shared alpha,beta,df,pdf,lf,plf,uf,puf,bf,cf,bcf,tf,tcf,xf,ds,pds,ls,pls,us,pus,bs,cs,bcs,ts,tcs,xs' >>$TESTS
-echo '%!test alpha=1; beta=1;' >> $TESTS
+echo '%!shared alpha,beta,df,pdf,lf,plf,uf,puf,bf,cf,bcf,tf,tcf,xf,ds,pds,ls,pls,us,pus,bs,cs,bcs,ts,tcs,xs'
+echo '%!test alpha=1; beta=1;'
 gen_solver_tests
-echo '%!test alpha=1; beta=1i;' >> $TESTS
+echo '%!test alpha=1; beta=1i;'
 gen_solver_tests
-echo '%!test alpha=1i; beta=1;' >> $TESTS
+echo '%!test alpha=1i; beta=1;'
 gen_solver_tests
-echo '%!test alpha=1i; beta=1i;' >> $TESTS
+echo '%!test alpha=1i; beta=1i;'
 gen_solver_tests
 gen_section
